@@ -37,7 +37,7 @@ GroupSwitcher::GroupSwitcher(View *view, GroupManager *gman, QWidget *parent)
     layout->addWidget(edit_group_policy);
     layout->addWidget(tool_bar);
     layout->addWidget(close_tab);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins(6, 0, 6, 0);
 
     new_tab->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     new_tab->setToolButtonStyle(Qt::ToolButtonIconOnly);
@@ -67,7 +67,7 @@ GroupSwitcher::~GroupSwitcher()
 
 void GroupSwitcher::loadState(KSharedConfig::Ptr cfg)
 {
-    KConfigGroup g = cfg->group("GroupSwitcher");
+    KConfigGroup g = cfg->group(QStringLiteral("GroupSwitcher"));
 
     QStringList default_groups;
     default_groups << QStringLiteral("/all") << QStringLiteral("/all/downloads") << QStringLiteral("/all/uploads");
@@ -78,7 +78,7 @@ void GroupSwitcher::loadState(KSharedConfig::Ptr cfg)
     }
 
     if (tabs.isEmpty()) {
-        for (const QString &group : qAsConst(default_groups))
+        for (const QString &group : std::as_const(default_groups))
             addTab(gman->findByPath(group));
     }
 
@@ -108,7 +108,7 @@ void GroupSwitcher::loadState(KSharedConfig::Ptr cfg)
 
 void GroupSwitcher::saveState(KSharedConfig::Ptr cfg)
 {
-    KConfigGroup g = cfg->group("GroupSwitcher");
+    KConfigGroup g = cfg->group(QStringLiteral("GroupSwitcher"));
     QStringList groups;
     int idx = 0;
     for (Tab &tab : tabs) {
@@ -182,7 +182,7 @@ void GroupSwitcher::onActivated(QAction *action)
     tabs[current_tab].view_settings = view->header()->saveState();
 
     int idx = 0;
-    for (const Tab &tab : qAsConst(tabs)) {
+    for (const Tab &tab : std::as_const(tabs)) {
         if (tab.action == action) {
             view->setGroup(tab.group);
             view->restoreState(tab.view_settings);
