@@ -32,7 +32,9 @@ void BWPrefPage::loadSettings()
 
 void BWPrefPage::updateSettings()
 {
-    colorsChanged();
+    Q_EMIT colorsChanged();
 }
 
 }
+
+#include "moc_bwprefpage.cpp"
