@@ -30,12 +30,11 @@ class LogViewerPlugin : public Plugin
 {
     Q_OBJECT
 public:
-    LogViewerPlugin(QObject *parent, const QVariantList &args);
+    LogViewerPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~LogViewerPlugin() override;
 
     void load() override;
     void unload() override;
-    bool versionCheck(const QString &version) const override;
     void guiUpdate() override;
 
 private Q_SLOTS:
@@ -46,11 +45,11 @@ private:
     void removeLogViewerFromGUI();
 
 private:
-    LogViewer *lv;
-    LogPrefPage *pref;
-    LogFlags *flags;
-    QDockWidget *dock;
-    LogViewerPosition pos;
+    LogViewer *lv = nullptr;
+    LogPrefPage *pref = nullptr;
+    LogFlags *flags = nullptr;
+    QDockWidget *dock = nullptr;
+    LogViewerPosition pos = SEPARATE_ACTIVITY;
 };
 
 }
