@@ -25,20 +25,19 @@ class ScanFolderPlugin : public Plugin
 {
     Q_OBJECT
 public:
-    ScanFolderPlugin(QObject *parent, const QVariantList &args);
+    ScanFolderPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~ScanFolderPlugin() override;
 
     void load() override;
     void unload() override;
-    bool versionCheck(const QString &version) const override;
 
 public Q_SLOTS:
     void updateScanFolders();
 
 private:
-    ScanFolderPrefPage *pref;
-    TorrentLoadQueue *tlq;
-    ScanThread *scanner;
+    ScanFolderPrefPage *pref = nullptr;
+    TorrentLoadQueue *tlq = nullptr;
+    ScanThread *scanner = nullptr;
 };
 
 }
