@@ -31,12 +31,11 @@ class ScanForLostFilesPlugin : public Plugin
 {
     Q_OBJECT
 public:
-    ScanForLostFilesPlugin(QObject *parent, const QVariantList &args);
+    ScanForLostFilesPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~ScanForLostFilesPlugin() override;
 
     void load() override;
     void unload() override;
-    bool versionCheck(const QString &version) const override;
 
 public Q_SLOTS:
     void updateScanForLostFiles();
@@ -46,10 +45,10 @@ private:
     void removeFromGUI();
 
 private:
-    ScanForLostFilesWidget *m_view;
-    QDockWidget *m_dock;
-    ScanForLostFilesPrefPage *m_pref;
-    SFLFPosition m_pos;
+    ScanForLostFilesWidget *m_view = nullptr;
+    QDockWidget *m_dock = nullptr;
+    ScanForLostFilesPrefPage *m_pref = nullptr;
+    SFLFPosition m_pos = SEPARATE_ACTIVITY;
 };
 
 }
