@@ -24,12 +24,11 @@ class ZeroConfPlugin : public Plugin
 {
     Q_OBJECT
 public:
-    ZeroConfPlugin(QObject *parent, const QVariantList &args);
+    ZeroConfPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~ZeroConfPlugin() override;
 
     void load() override;
     void unload() override;
-    bool versionCheck(const QString &version) const override;
 
 private Q_SLOTS:
     /**
